@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,7 +9,8 @@
 #include "grantleethemeeditor_export.h"
 #include <QDialog>
 
-namespace GrantleeThemeEditor {
+namespace GrantleeThemeEditor
+{
 class ManageThemesPrivate;
 class GRANTLEETHEMEEDITOR_EXPORT ManageThemes : public QDialog
 {
